==> ical4j-3.2.18-sources.jar: net/fortuna/ical4j/validate/ValidationReport.java <==
/*
 *  Copyright (c) 2022, Ben Fortuna
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   o Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *   o Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *
 *   o Neither the name of Ben Fortuna nor the names of any other contributors
 *  may be used to endorse or promote products derived from this software
 *  without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package net.fortuna.ical4j.validate;

import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.nio.charset.StandardCharsets;

/**
 * Generate a report from a {@link ValidationResult}.
 */
public class ValidationReport {

    public enum Format {
        HTML, TEXT
    }

    private final Format format;

    public ValidationReport() {
        this(Format.HTML);
    }

    public ValidationReport(Format format) {
        this.format = format;
    }

    public void output(ValidationResult result, OutputStream out) throws IOException {
        output(result, new OutputStreamWriter(out, StandardCharsets.UTF_8));
    }

    public void output(ValidationResult result, Writer out) throws IOException {
        switch (format) {
            case HTML: outputHtml(result, out); break;
            case TEXT: outputText(result, out); break;
        }
    }

    private void outputHtml(ValidationResult result, Writer out) throws IOException {
        out.write("<ol>");
        for (ValidationEntry entry : result.getEntries()) {
            out.write(String.format("<li>%s: %s - %s</li>\n", entry.getContext(), entry.getSeverity(), entry.getMessage()));
        }
        out.write("</ol>");
    }

    private void outputText(ValidationResult result, Writer out) throws IOException {
        for (ValidationEntry entry : result.getEntries()) {
            out.write(String.format("- %s: %s - %s\n", entry.getSeverity(), entry.getContext(), entry.getMessage()));
        }
    }
}

==> ical4j-4.0.5-sources.jar: net/fortuna/ical4j/validate/ValidationReport.java <==
/*
 *  Copyright (c) 2022, Ben Fortuna
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   o Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *   o Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *
 *   o Neither the name of Ben Fortuna nor the names of any other contributors
 *  may be used to endorse or promote products derived from this software
 *  without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package net.fortuna.ical4j.validate;

import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.nio.charset.StandardCharsets;

/**
 * Generate a report from a {@link ValidationResult}.
 */
public class ValidationReport {

    public enum Format {
        HTML, TEXT
    }

    private final Format format;

    public ValidationReport() {
        this(Format.HTML);
    }

    public ValidationReport(Format format) {
        this.format = format;
    }

    public void output(ValidationResult result, OutputStream out) throws IOException {
        output(result, new OutputStreamWriter(out, StandardCharsets.UTF_8));
    }

    public void output(ValidationResult result, Writer out) throws IOException {
        switch (format) {
            case HTML: outputHtml(result, out); break;
            case TEXT: outputText(result, out); break;
        }
    }

    private void outputHtml(ValidationResult result, Writer out) throws IOException {
        out.write("<ol>");
        for (var entry : result.getEntries()) {
            out.write(String.format("<li>%s: %s - %s</li>\n", entry.getContext(), entry.getSeverity(), entry.getMessage()));
        }
        out.write("</ol>");
    }

    private void outputText(ValidationResult result, Writer out) throws IOException {
        for (var entry : result.getEntries()) {
            out.write(String.format("- %s: %s - %s\n", entry.getSeverity(), entry.getContext(), entry.getMessage()));
        }
    }
}
